pub struct Tab32Mixed { /* private fields */ }Expand description
A hash function for 32-bit integers using mixed tabulation.
Mixed tabulation first hashes the four input bytes into a 32-bit intermediate
hash value and four derived bytes. The derived bytes are then hashed by a
second simple tabulation function and XORed into the intermediate value.
This implementation uses c = d = 4, where c is the number of input
characters and d is the number of derived characters.
Usage:
use tab_hash::Tab32Mixed;
let keys = vec![0, 8, 15, 47, 11];
let mixed = Tab32Mixed::new();
for k in keys {
println!("{}", mixed.hash(k));
}Implementations
Sourceimpl Tab32Mixed
impl Tab32Mixed
Sourcepub fn to_vec(&self) -> (Vec<Vec<u64>>, Vec<Vec<u32>>)
pub fn to_vec(&self) -> (Vec<Vec<u64>>, Vec<Vec<u32>>)
Convert the two tables to nested vectors.
Sourcepub fn from_vec(
first_table_data: Vec<Vec<u64>>,
second_table_data: Vec<Vec<u32>>,
) -> Self
pub fn from_vec( first_table_data: Vec<Vec<u64>>, second_table_data: Vec<Vec<u32>>, ) -> Self
Create a mixed tabulation hash function from nested-vector table data.
Sourcepub fn with_table(
first_table: [[u64; 256]; 4],
second_table: [[u32; 256]; 4],
) -> Self
pub fn with_table( first_table: [[u64; 256]; 4], second_table: [[u32; 256]; 4], ) -> Self
Create a mixed tabulation hash function with the given tables.